@@ -24,6 +24,7 @@ from chainlib.eth.cli.arg import (
         Arg,
         ArgFlag,
         process_args,
+        stdin_arg,
         )
 from chainlib.eth.cli.config import (
         Config,
@@ -37,6 +38,7 @@ from chainlib.eth.gas import (
         balance,
         )
 from chainlib.eth.settings import process_settings
+from chainlib.eth.jsonrpc import to_blockheight_param
 
 
 logg = logging.getLogger()
@@ -45,7 +47,13 @@ script_dir = os.path.dirname(os.path.realpath(__file__))
 
 
 def process_config_local(config, arg, args, flags):
-    config.add(args.address, '_RECIPIENT', False)
+    recipient = None
+    address = config.get('_POSARG')
+    if address:
+        recipient = add_0x(address)
+    else:
+        recipient = stdin_arg()
+    config.add(recipient, '_RECIPIENT', False)
     return config
 
 
@@ -55,15 +63,15 @@ flags = arg_flags.STD_READ
 
 argparser = chainlib.eth.cli.ArgumentParser()
 argparser = process_args(argparser, arg, flags)
-
 argparser.add_argument('address', type=str, help='Ethereum address of recipient')
+
 args = argparser.parse_args()
 
 logg = process_log(args, logg)
 logg.debug('flags {} {} {}'.format(flags, arg_flags.SEQ, flags & arg_flags.SEQ))
 
 config = Config()
-config = process_config(config, arg, args, flags)
+config = process_config(config, arg, args, flags, positional_name='address')
 config = process_config_local(config, arg, args, flags)
 logg.debug('config loaded:\n{}'.format(config))
 
@@ -75,7 +83,8 @@ def main():
     r = None
     decimals = 18
 
-    o = balance(settings.get('RECIPIENT'), id_generator=settings.get('RPC_ID_GENERATOR'))
+    height = to_blockheight_param(config.get('_HEIGHT'))
+    o = balance(settings.get('RECIPIENT'), id_generator=settings.get('RPC_ID_GENERATOR'), height=height)
     r = settings.get('CONN').do(o)
    
     hx = strip_0x(r)
@@ -84,11 +93,14 @@ def main():
 
     balance_str = str(balance_value)
     balance_len = len(balance_str)
-    if balance_len < decimals + 1:
-        print('0.{}'.format(balance_str.zfill(decimals)))
+    if config.get('_RAW'):
+        print(balance_str)
     else:
-        offset = balance_len-decimals
-        print('{}.{}'.format(balance_str[:offset],balance_str[offset:]))
+        if balance_len < decimals + 1:
+            print('0.{}'.format(balance_str.zfill(decimals)))
+        else:
+            offset = balance_len-decimals
+            print('{}.{}'.format(balance_str[:offset],balance_str[offset:]))
 
 
 if __name__ == '__main__':
